@@ -21,14 +21,14 @@ from .pandas_hello_world.pipeline import pandas_hello_world
 
 
 def nb_test_path(name):
-    return file_relative_path(__file__, 'notebooks/{name}.ipynb'.format(name=name))
+    return file_relative_path(__file__, "notebooks/{name}.ipynb".format(name=name))
 
 
 def define_papermill_pandas_hello_world_solid():
     return dagstermill.define_dagstermill_solid(
-        name='papermill_pandas_hello_world',
-        notebook_path=nb_test_path('papermill_pandas_hello_world'),
-        input_defs=[InputDefinition(name='df', dagster_type=DataFrame)],
+        name="papermill_pandas_hello_world",
+        notebook_path=nb_test_path("papermill_pandas_hello_world"),
+        input_defs=[InputDefinition(name="df", dagster_type=DataFrame)],
         output_defs=[OutputDefinition(DataFrame)],
     )
 
@@ -36,20 +36,20 @@ def define_papermill_pandas_hello_world_solid():
 @pipeline(
     preset_defs=[
         PresetDefinition.from_files(
-            'test',
-            environment_files=[
+            "test",
+            config_files=[
                 file_relative_path(
                     __file__,
-                    'pandas_hello_world/environments/papermill_pandas_hello_world_test.yaml',
+                    "pandas_hello_world/environments/papermill_pandas_hello_world_test.yaml",
                 )
             ],
         ),
         PresetDefinition.from_files(
-            'prod',
-            environment_files=[
+            "prod",
+            config_files=[
                 file_relative_path(
                     __file__,
-                    'pandas_hello_world/environments/papermill_pandas_hello_world_prod.yaml',
+                    "pandas_hello_world/environments/papermill_pandas_hello_world_prod.yaml",
                 )
             ],
         ),
